//
// C++ Implementation: %{MODULE}
//
// Description:
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgdomainconstraint.h"

// include files for KDE
#include <kdebug.h>
#include <klocale.h>

#include "kpgdomainconstraintsfolder.h"
#include "kpgconnection.h"


KPGDomainConstraint::KPGDomainConstraint(KPGDomainConstraintsFolder *parent, const QString name, pqxx::oid _oid)
  : KPGObject(parent, name, _oid)
{
    setPixmap(0, *m_pIconCheckConstr);
}

KPGDomainConstraint::KPGDomainConstraint(KPGDomainConstraintsFolder *parent, KPGDomainConstraint *after, const QString name, pqxx::oid _oid)
  : KPGObject(parent, after, name, _oid)
{
    setPixmap(0, *m_pIconCheckConstr);
}

KPGDomainConstraint::~KPGDomainConstraint()
{
}

void KPGDomainConstraint::setProperties(const pqxx::result::tuple &pqxxTuple,
										const KPGConnection *pConnection)
{
	m_strDescription = pConnection->toUnicode(pqxxTuple["description"].c_str());
    m_strExpression = pqxxTuple["consrc"].c_str();
    m_strNspName = pqxxTuple["nspname"].c_str();
}

